quantizationtools.MeasurewiseQSchemaItem
========================================

.. abjad-lineage:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem

.. autoclass:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.beatspan
      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.search_tree
      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.tempo
      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.time_signature
      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.use_full_measure
      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.__eq__
      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.__format__
      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.__ne__
      ~abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.__repr__

Bases
-----

- :py:class:`quantizationtools.QSchemaItem <abjad.tools.quantizationtools.QSchemaItem.QSchemaItem>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.beatspan
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.tempo
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.time_signature
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.use_full_measure
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.MeasurewiseQSchemaItem.MeasurewiseQSchemaItem.__repr__
   :noindex:
